[![Build Status](https://travis-ci.org/idr/idr-python.png)](http://travis-ci.org/idr/idr-python)

IDR Python
==========

Library with helper methods for accessing the Image Data Resource (IDR).

Requirements
============

* OMERO.py 5.3.x
* Python 2.6+

License
=======

This project, similar to many Open Microscopy Environment (OME) projects, is
licensed under the terms of the GNU General Public License (GPL) v2 or later.
